@@ -11,7 +11,7 @@ import rforum.models as mymodels
 
 register = template.Library()
 
-@register.inclusion_tag('rforum/elements/widget_lastposts.html')
+@register.inclusion_tag('rforum/_widget_lastposts.html')
 def last_posts(num):
 
     """
@@ -21,7 +21,7 @@ def last_posts(num):
     return { 'lastposts': lastposts }
 
 
-@register.inclusion_tag('rforum/elements/widget_lastnews.html')
+@register.inclusion_tag('rforum/_widget_lastnews.html')
 def last_news(num):
 
     """
@@ -32,7 +32,7 @@ def last_news(num):
     return { 'topics': topics }
 
 
-@register.inclusion_tag('rforum/elements/widget_onlineusers.html')
+@register.inclusion_tag('rforum/_widget_onlineusers.html')
 def online_users(num):
     """
     Show user that has been login an hour ago.
@@ -53,7 +53,7 @@ def online_users(num):
                                     is_active__exact=1).order_by('-last_login')[:num]
     return { 'users': users, 'anon': random.randrange(60,78,1) }
 
-@register.inclusion_tag('rforum/elements/widget_lastregisters.html')
+@register.inclusion_tag('rforum/_widget_lastregisters.html')
 def last_registers(num):
     """
     Show last registered users.
@@ -74,7 +74,7 @@ def last_registers(num):
         users = User.objects.filter(is_active=True).order_by('-date_joined')[:num]
     return { 'users': users }
 
-@register.inclusion_tag('rforum/elements/widget_lastlogins.html')
+@register.inclusion_tag('rforum/_widget_lastlogins.html')
 def last_logins(num):
     """
     Show last logins ...
@@ -87,7 +87,7 @@ def last_logins(num):
     return { 'users': users }
 
 
-@register.inclusion_tag('rforum/elements/widget_stats.html')
+@register.inclusion_tag('rforum/_widget_stats.html')
 def stats():
     """
     Show forum stats...
